==> haskell-pipes-4.3.7-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-pipes.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pipes
version: 4.3.7
id: pipes-4.3.7-3scLRU5CqV4FW8aZ6ULnmK
key: pipes-4.3.7-3scLRU5CqV4FW8aZ6ULnmK
license: BSD3
copyright: 2012-2016 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
synopsis: Compositional pipelines
description:
    `pipes` is a clean and powerful stream processing library that lets you build
    and connect reusable streaming components
    .
    Advantages over traditional streaming libraries:
    .
    * /Concise API/: Use simple commands like '\''for'\'', ('\''>->'\''), '\''await'\'', and '\''yield'\''
    .
    * /Blazing fast/: Implementation tuned for speed, including shortcut fusion
    .
    * /Lightweight Dependency/: @pipes@ is small and compiles very rapidly,
    including dependencies
    .
    * /Elegant semantics/: Use practical category theory
    .
    * /ListT/: Correct implementation of '\''ListT'\'' that interconverts with pipes
    .
    * /Bidirectionality/: Implement duplex channels
    .
    * /Extensive Documentation/: Second to none!
    .
    Import "Pipes" to use the library.
    .
    Read "Pipes.Tutorial" for an extensive tutorial.
category: Control, Pipes
author: Gabriel Gonzalez
exposed: True
indefinite: False
exposed-modules:
    Pipes Pipes.Core Pipes.Internal Pipes.Lift Pipes.Prelude
    Pipes.Tutorial
abi: 249384811c2730fa9ad419653edc4090
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/pipes-4.3.7
library-dirs: /usr/lib/ghc-8.2.2/site-local/pipes-4.3.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/pipes-4.3.7
hs-libraries: HSpipes-4.3.7-3scLRU5CqV4FW8aZ6ULnmK
depends:
    base-4.10.1.0 transformers-0.5.2.0
    exceptions-0.8.3-FtqgxeR4VUg9hGcIqYr2bq
    mmorph-1.1.1-JSXAlwXaEvB9wEd1iGFnPP
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc void-0.7.2-FiGeS4PZxPp8gUDrtvjFKC
    semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             exceptions-0.8.3-FtqgxeR4VUg9hGcIqYr2bq=349f1b5172af08123dc6c444b05979b3
             mmorph-1.1.1-JSXAlwXaEvB9wEd1iGFnPP=95d13a4e892cac98ce59ec611b08550c
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             void-0.7.2-FiGeS4PZxPp8gUDrtvjFKC=a5672067c7a1184b41916f0fb2d0c330
             semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q=0f8a4b2bc8ee8ce3a5dab66f0eb14e7c
haddock-interfaces: /usr/share/doc/haskell-pipes/html/pipes.haddock
haddock-html: /usr/share/doc/haskell-pipes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pipes-4.3.8-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-pipes.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pipes
version: 4.3.8
id: pipes-4.3.8-B2Af1kMZBlPKiMEg0RQtla
key: pipes-4.3.8-B2Af1kMZBlPKiMEg0RQtla
license: BSD3
copyright: 2012-2016 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
synopsis: Compositional pipelines
description:
    `pipes` is a clean and powerful stream processing library that lets you build
    and connect reusable streaming components
    .
    Advantages over traditional streaming libraries:
    .
    * /Concise API/: Use simple commands like '\''for'\'', ('\''>->'\''), '\''await'\'', and '\''yield'\''
    .
    * /Blazing fast/: Implementation tuned for speed, including shortcut fusion
    .
    * /Lightweight Dependency/: @pipes@ is small and compiles very rapidly,
    including dependencies
    .
    * /Elegant semantics/: Use practical category theory
    .
    * /ListT/: Correct implementation of '\''ListT'\'' that interconverts with pipes
    .
    * /Bidirectionality/: Implement duplex channels
    .
    * /Extensive Documentation/: Second to none!
    .
    Import "Pipes" to use the library.
    .
    Read "Pipes.Tutorial" for an extensive tutorial.
category: Control, Pipes
author: Gabriel Gonzalez
exposed: True
indefinite: False
exposed-modules:
    Pipes Pipes.Core Pipes.Internal Pipes.Lift Pipes.Prelude
    Pipes.Tutorial
abi: ecb6df2b314de231492b4ce8d93f3474
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/pipes-4.3.8
library-dirs: /usr/lib/ghc-8.2.2/site-local/pipes-4.3.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/pipes-4.3.8
hs-libraries: HSpipes-4.3.8-B2Af1kMZBlPKiMEg0RQtla
depends:
    base-4.10.1.0 transformers-0.5.2.0
    exceptions-0.8.3-FtqgxeR4VUg9hGcIqYr2bq
    mmorph-1.1.1-JSXAlwXaEvB9wEd1iGFnPP
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc void-0.7.2-FiGeS4PZxPp8gUDrtvjFKC
    semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             exceptions-0.8.3-FtqgxeR4VUg9hGcIqYr2bq=349f1b5172af08123dc6c444b05979b3
             mmorph-1.1.1-JSXAlwXaEvB9wEd1iGFnPP=95d13a4e892cac98ce59ec611b08550c
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             void-0.7.2-FiGeS4PZxPp8gUDrtvjFKC=a5672067c7a1184b41916f0fb2d0c330
             semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q=0f8a4b2bc8ee8ce3a5dab66f0eb14e7c
haddock-interfaces: /usr/share/doc/haskell-pipes/html/pipes.haddock
haddock-html: /usr/share/doc/haskell-pipes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
